@@ -120,8 +120,10 @@ class Tumblpy(object):
             if method == 'get':
                 response = func(url, params=params, allow_redirects=False)
             else:
-                response = func(url, params=params, data=params, files=files,
-                                allow_redirects=False)
+                kwargs = {'data': params, 'files': files, 'allow_redirects': False}
+                if files:
+                    kwargs['params'] = params
+                response = func(url, **kwargs)
         except requests.exceptions.RequestException:
             raise TumblpyError('An unknown error occurred.')
 
